==> haskell-sourcemap-0.1.6-97-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-sourcemap.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: sourcemap
version: 0.1.6
id: sourcemap-0.1.6-Hd6Ot0VmVBdGrBgfZ1oeIV
key: sourcemap-0.1.6-Hd6Ot0VmVBdGrBgfZ1oeIV
license: BSD-3-Clause
copyright: 2012 Chris Done
maintainer: chrisdone@gmail.com
author: Chris Done
stability: alpha
synopsis: Implementation of source maps as proposed by Google and Mozilla.
description:
    Implementation of source maps, revision 3, proposed by Google and Mozilla here
    <https://wiki.mozilla.org/DevTools/Features/SourceMap> and here
    <https://docs.google.com/document/d/1U1RGAehQwRypUTovF1KRlpiOFze0b-_2gc6fAH0KY0k/edit>
category: Development
abi: 5ce1a624d04beba1827497d0b32de441
exposed: True
exposed-modules:
    SourceMap SourceMap.Types
hidden-modules: VLQ
import-dirs: /usr/lib/ghc-8.6.1/site-local/sourcemap-0.1.6
library-dirs: /usr/lib/ghc-8.6.1/site-local/sourcemap-0.1.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/sourcemap-0.1.6
hs-libraries: HSsourcemap-0.1.6-Hd6Ot0VmVBdGrBgfZ1oeIV
depends:
    aeson-1.4.1.0-AhBumTS0oTGDeYkHnhbKOg
    attoparsec-0.13.2.2-FwHjzt71DhSHhjVAq259Rs base-4.12.0.0
    bytestring-0.10.8.2 process-1.6.3.0 text-1.2.3.1
    unordered-containers-0.2.9.0-8YwmaeVELNEGd3AzVghTJw
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/haskell-sourcemap/html/sourcemap.haddock
haddock-html: /usr/share/doc/haskell-sourcemap/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sourcemap-0.1.6-98-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-sourcemap.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: sourcemap
version: 0.1.6
id: sourcemap-0.1.6-JBCOtH187P472J1UmQeUFt
key: sourcemap-0.1.6-JBCOtH187P472J1UmQeUFt
license: BSD-3-Clause
copyright: 2012 Chris Done
maintainer: chrisdone@gmail.com
author: Chris Done
stability: alpha
synopsis: Implementation of source maps as proposed by Google and Mozilla.
description:
    Implementation of source maps, revision 3, proposed by Google and Mozilla here
    <https://wiki.mozilla.org/DevTools/Features/SourceMap> and here
    <https://docs.google.com/document/d/1U1RGAehQwRypUTovF1KRlpiOFze0b-_2gc6fAH0KY0k/edit>
category: Development
abi: e0b6ded96012fe47bae26d03be3e6ec8
exposed: True
exposed-modules:
    SourceMap SourceMap.Types
hidden-modules: VLQ
import-dirs: /usr/lib/ghc-8.6.1/site-local/sourcemap-0.1.6
library-dirs: /usr/lib/ghc-8.6.1/site-local/sourcemap-0.1.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/sourcemap-0.1.6
hs-libraries: HSsourcemap-0.1.6-JBCOtH187P472J1UmQeUFt
depends:
    aeson-1.4.1.0-8dof3cdgEra8LhpTdWgCQb
    attoparsec-0.13.2.2-HPD0YgNwhBr5J2x8QxeYlI base-4.12.0.0
    bytestring-0.10.8.2 process-1.6.3.0 text-1.2.3.1
    unordered-containers-0.2.9.0-LB7iMl6A8usDj0EAzhnafU
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/haskell-sourcemap/html/sourcemap.haddock
haddock-html: /usr/share/doc/haskell-sourcemap/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
